Avulto: A BYOND Python Library
==============================

Avulto_ is a Python library used to interact with BYOND codebases; primarily
Space Station 13 codebases. It is built on top of the Rust library
SpacemanDMM_, and is fast and versatile.

.. _Avulto: https://pypi.org/project/avulto/
.. _SpacemanDMM: https://github.com/SpaceManiac/SpacemanDMM/


.. toctree::
   Introduction <self>

.. toctree::
   quickstart

API Reference
*************

.. toctree::
   api/primitives
   api/dme
   api/dmi
   api/dmm
   :maxdepth: 2
